ASI Embedding Package
=====================

Submodules
----------

asiembedding.atoms\_embedding\_asi module
-------------------------------------------

.. automodule:: asiembedding.atoms_embedding_asi
   :members:
   :undoc-members:
   :show-inheritance:

asiembedding.basis\_info module
---------------------------------

.. automodule:: asiembedding.basis_info
   :members:
   :undoc-members:
   :show-inheritance:

asiembedding.embedding module
-------------------------------

.. automodule:: asiembedding.embedding
   :members:
   :undoc-members:
   :show-inheritance:

asiembedding.parallel\_utils module
-------------------------------------

.. automodule:: asiembedding.parallel_utils
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: asiembedding
   :members:
   :undoc-members:
   :show-inheritance:
